==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/integrationspaces/kotlin/inputs/ListApplicationBusinessProcessDevelopmentArtifactsPlainArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.integrationspaces.kotlin.inputs

import com.pulumi.azurenative.integrationspaces.inputs.ListApplicationBusinessProcessDevelopmentArtifactsPlainArgs.builder
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property applicationName The name of the Application
 * @property resourceGroupName The name of the resource group. The name is case insensitive.
 * @property spaceName The name of the space
 */
public data class ListApplicationBusinessProcessDevelopmentArtifactsPlainArgs(
    public val applicationName: String,
    public val resourceGroupName: String,
    public val spaceName: String,
) :
    ConvertibleToJava<com.pulumi.azurenative.integrationspaces.inputs.ListApplicationBusinessProcessDevelopmentArtifactsPlainArgs> {
    override fun toJava():
        com.pulumi.azurenative.integrationspaces.inputs.ListApplicationBusinessProcessDevelopmentArtifactsPlainArgs =
        com.pulumi.azurenative.integrationspaces.inputs.ListApplicationBusinessProcessDevelopmentArtifactsPlainArgs.builder()
            .applicationName(applicationName.let({ args0 -> args0 }))
            .resourceGroupName(resourceGroupName.let({ args0 -> args0 }))
            .spaceName(spaceName.let({ args0 -> args0 })).build()
}

/**
 * Builder for [ListApplicationBusinessProcessDevelopmentArtifactsPlainArgs].
 */
@PulumiTagMarker
public class ListApplicationBusinessProcessDevelopmentArtifactsPlainArgsBuilder internal
constructor() {
    private var applicationName: String? = null

    private var resourceGroupName: String? = null

    private var spaceName: String? = null

    /**
     * @param value The name of the Application
     */
    @JvmName("dvarwpycxivkkipx")
    public suspend fun applicationName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.applicationName = mapped
    }

    /**
     * @param value The name of the resource group. The name is case insensitive.
     */
    @JvmName("taljkvphikfdpwwx")
    public suspend fun resourceGroupName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.resourceGroupName = mapped
    }

    /**
     * @param value The name of the space
     */
    @JvmName("gjlwetuarxwvqmhk")
    public suspend fun spaceName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.spaceName = mapped
    }

    internal fun build(): ListApplicationBusinessProcessDevelopmentArtifactsPlainArgs =
        ListApplicationBusinessProcessDevelopmentArtifactsPlainArgs(
            applicationName = applicationName ?: throw PulumiNullFieldException("applicationName"),
            resourceGroupName = resourceGroupName ?: throw PulumiNullFieldException("resourceGroupName"),
            spaceName = spaceName ?: throw PulumiNullFieldException("spaceName"),
        )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/integrationspaces/kotlin/inputs/ListApplicationBusinessProcessDevelopmentArtifactsPlainArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.integrationspaces.kotlin.inputs

import com.pulumi.azurenative.integrationspaces.inputs.ListApplicationBusinessProcessDevelopmentArtifactsPlainArgs.builder
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property applicationName The name of the Application
 * @property resourceGroupName The name of the resource group. The name is case insensitive.
 * @property spaceName The name of the space
 */
public data class ListApplicationBusinessProcessDevelopmentArtifactsPlainArgs(
    public val applicationName: String,
    public val resourceGroupName: String,
    public val spaceName: String,
) :
    ConvertibleToJava<com.pulumi.azurenative.integrationspaces.inputs.ListApplicationBusinessProcessDevelopmentArtifactsPlainArgs> {
    override fun toJava():
        com.pulumi.azurenative.integrationspaces.inputs.ListApplicationBusinessProcessDevelopmentArtifactsPlainArgs =
        com.pulumi.azurenative.integrationspaces.inputs.ListApplicationBusinessProcessDevelopmentArtifactsPlainArgs.builder()
            .applicationName(applicationName.let({ args0 -> args0 }))
            .resourceGroupName(resourceGroupName.let({ args0 -> args0 }))
            .spaceName(spaceName.let({ args0 -> args0 })).build()
}

/**
 * Builder for [ListApplicationBusinessProcessDevelopmentArtifactsPlainArgs].
 */
@PulumiTagMarker
public class ListApplicationBusinessProcessDevelopmentArtifactsPlainArgsBuilder internal
constructor() {
    private var applicationName: String? = null

    private var resourceGroupName: String? = null

    private var spaceName: String? = null

    /**
     * @param value The name of the Application
     */
    @JvmName("hvintfnqvlxphsjo")
    public suspend fun applicationName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.applicationName = mapped
    }

    /**
     * @param value The name of the resource group. The name is case insensitive.
     */
    @JvmName("whbsbsolsxfhhkvq")
    public suspend fun resourceGroupName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.resourceGroupName = mapped
    }

    /**
     * @param value The name of the space
     */
    @JvmName("hsiyhbjrlskgclyg")
    public suspend fun spaceName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.spaceName = mapped
    }

    internal fun build(): ListApplicationBusinessProcessDevelopmentArtifactsPlainArgs =
        ListApplicationBusinessProcessDevelopmentArtifactsPlainArgs(
            applicationName = applicationName ?: throw PulumiNullFieldException("applicationName"),
            resourceGroupName = resourceGroupName ?: throw PulumiNullFieldException("resourceGroupName"),
            spaceName = spaceName ?: throw PulumiNullFieldException("spaceName"),
        )
}
